@@ -1,8 +1,9 @@
 package Encode::IBM;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
  
 use Encode;
 use XSLoader;
+use Encode::IBM::835SOSI;
 use Encode::IBM::947SOSI;
 XSLoader::load(__PACKAGE__,$VERSION);
 
@@ -15,8 +16,8 @@ Encode::IBM - IBM-specific encoding mappings
 
 =head1 VERSION
 
-This document describes version 0.04 of Encode::IBM, released
-September 16, 2006.
+This document describes version 0.05 of Encode::IBM, released
+September 28, 2006.
  
 =head1 SYNOPSIS
 
@@ -25,6 +26,15 @@ September 16, 2006.
     binmode( STDIN, ':encoding(ibm-835)' );
     binmode( STDOUT, ':encoding(ibm-947-sosi)' );
 
+=head1 ENCODINGS
+
+    ibm-835
+    ibm-937
+    ibm-947
+
+    ibm-835-sosi
+    ibm-947-sosi
+
 =head1 SEE ALSO
 
 L<Encode>
