@@ -58,6 +58,8 @@ __END__
 
 =head1 NAME
 
-Encode::Unisys::SOSI1
+Encode::IBM::947SOSI
+
+=cut
 
 =cut
